@@ -15,8 +15,8 @@ describe Puppet::Provider::Mistral do
 
     it 'should fail if no auth params are passed and the mistral config file does not have the expected contents' do
       mock = {}
-      Puppet::Util::IniConfig::File.expects(:new).returns(mock)
-      mock.expects(:read).with('/etc/mistral/mistral.conf')
+      expect(Puppet::Util::IniConfig::File).to receive(:new).and_return(mock)
+      expect(mock).to receive(:read).with('/etc/mistral/mistral.conf')
       expect do
         klass.mistral_credentials
       end.to raise_error(Puppet::Error, /Mistral types will not work/)
@@ -39,8 +39,8 @@ describe Puppet::Provider::Mistral do
           'password'     => 'password',
         }
       }
-      Puppet::Util::IniConfig::File.expects(:new).returns(mock)
-      mock.expects(:read).with('/etc/mistral/mistral.conf')
+      expect(Puppet::Util::IniConfig::File).to receive(:new).and_return(mock)
+      expect(mock).to receive(:read).with('/etc/mistral/mistral.conf')
       expect(klass.mistral_credentials).to eq(creds_hash)
     end
 
